@@ -14,57 +14,50 @@ class Request(object):
     Http request object.
     """
 
-    def __init__(self, username, password, content_type, timeout=30):
+    def __init__(self, username, password, content_type):
         self.username = username
         self.password = password
         self.content_type = content_type
-        self.timeout = timeout
 
-    def get(self, url, params=None):
+    def get(self, url, params=None, timeout=30):
         """
         Make a GET request to CUBE.
         """
         headers = {'Content-Type': self.content_type, 'Accept': self.content_type}
         try:
-            if self.username or self.password:
-                r = requests.get(url,
-                                 params=params,
-                                 auth=(self.username, self.password),
-                                 timeout=self.timeout, headers=headers)
-            else:
-                r = requests.get(url, params=params, timeout=self.timeout,
-                                 headers=headers)
+            r = requests.get(url,
+                             params=params,
+                             auth=(self.username, self.password),
+                             timeout=timeout,
+                             headers=headers)
         except (requests.exceptions.Timeout, requests.exceptions.RequestException) as e:
             raise ChrisRequestException(str(e))
         return self.get_collection_from_response(r)
 
-    def post(self, url, data, descriptor_file=None):
+    def post(self, url, data, descriptor_file=None, timeout=30):
         """
         Make a POST request to CUBE.
         """
-        return self._post_put(requests.post, url, data, descriptor_file)
+        return self._post_put(requests.post, url, data, descriptor_file, timeout)
 
-    def put(self, url, data, descriptor_file=None):
+    def put(self, url, data, descriptor_file=None, timeout=30):
         """
         Make a PUT request to CUBE.
         """
-        return self._post_put(requests.put, url, data, descriptor_file)
+        return self._post_put(requests.put, url, data, descriptor_file, timeout)
 
-    def delete(self, url):
+    def delete(self, url, timeout=30):
         """
         Make a DELETE request to CUBE.
         """
         try:
-            if self.username or self.password:
-                r = requests.delete(url,
-                                    auth=(self.username, self.password),
-                                    timeout=self.timeout)
-            else:
-                r = requests.delete(url, timeout=self.timeout)
+            r = requests.delete(url,
+                                auth=(self.username, self.password),
+                                timeout=timeout)
         except (requests.exceptions.Timeout, requests.exceptions.RequestException) as e:
             raise ChrisRequestException(str(e))
 
-    def _post_put(self, request_method, url, data, fname=None):
+    def _post_put(self, request_method, url, data, fname=None, timeout=30):
         """
         Internal method to make either a POST or PUT request to CUBE.
         """
@@ -77,13 +70,9 @@ class Request(object):
             headers = None
             files = {'fname': fname}
         try:
-            if self.username or self.password:
-                r = request_method(url, files=files, data=data,
-                                   auth=(self.username, self.password),
-                                   timeout=self.timeout, headers=headers)
-            else:
-                r = request_method(url, files=files, data=data, timeout=self.timeout,
-                                   headers=headers)
+            r = request_method(url, files=files, data=data,
+                               auth=(self.username, self.password),
+                               timeout=timeout, headers=headers)
         except (requests.exceptions.Timeout, requests.exceptions.RequestException) as e:
             raise ChrisRequestException(str(e))
         return self.get_collection_from_response(r)
